@@ -17,10 +17,12 @@ vector<string> ClassifyOtuCommand::setParameters(){
 	try {
 		CommandParameter plist("list", "InputTypes", "", "", "none", "none", "none","",false,true,true); parameters.push_back(plist);
 		CommandParameter ptaxonomy("taxonomy", "InputTypes", "", "", "none", "none", "none","constaxonomy",false,true,true); parameters.push_back(ptaxonomy);
-		CommandParameter preftaxonomy("reftaxonomy", "InputTypes", "", "", "none", "none", "none","",false,false); parameters.push_back(preftaxonomy);
         CommandParameter pname("name", "InputTypes", "", "", "NameCount", "none", "none","",false,false,true); parameters.push_back(pname);
         CommandParameter pcount("count", "InputTypes", "", "", "NameCount-CountGroup", "none", "none","",false,false,true); parameters.push_back(pcount);
-		CommandParameter pgroup("group", "InputTypes", "", "", "CountGroup", "none", "none","",false,false,true); parameters.push_back(pgroup);
+        CommandParameter poutput("output", "Multiple", "plain-detail", "detail", "", "", "","",false,false, true); parameters.push_back(poutput);
+        CommandParameter pgroup("group", "InputTypes", "", "", "CountGroup", "none", "none","",false,false,true); parameters.push_back(pgroup);
+        CommandParameter prelabund("relabund", "Boolean", "", "F", "", "", "","",false,false); parameters.push_back(prelabund);
+        CommandParameter pprintlevel("printlevel", "Number", "", "-1", "", "", "","",false,false); parameters.push_back(pprintlevel);
         CommandParameter ppersample("persample", "Boolean", "", "F", "", "", "","",false,false); parameters.push_back(ppersample);
         CommandParameter plabel("label", "String", "", "", "", "", "","",false,false); parameters.push_back(plabel);
 		CommandParameter pbasis("basis", "Multiple", "otu-sequence", "otu", "", "", "","",false,false); parameters.push_back(pbasis);
@@ -44,8 +46,7 @@ vector<string> ClassifyOtuCommand::setParameters(){
 string ClassifyOtuCommand::getHelpString(){	
 	try {
 		string helpString = "";
-		helpString += "The classify.otu command parameters are list, taxonomy, reftaxonomy, name, group, count, persample, cutoff, label, basis and probs.  The taxonomy and list parameters are required unless you have a valid current file.\n";
-		helpString += "The reftaxonomy parameter allows you give the name of the reference taxonomy file used when you classified your sequences. Providing it will keep the rankIDs in the summary file static.\n";
+		helpString += "The classify.otu command parameters are list, taxonomy, name, group, count, persample, cutoff, label, basis, relabund and probs.  The taxonomy and list parameters are required unless you have a valid current file.\n";
 		helpString += "The name parameter allows you add a names file with your taxonomy file.\n";
 		helpString += "The group parameter allows you provide a group file to use in creating the summary file breakdown.\n";
 		helpString += "The count parameter allows you add a count file associated with your list file. When using the count parameter mothur assumes your list file contains only uniques.\n";
@@ -56,7 +57,10 @@ string ClassifyOtuCommand::getHelpString(){
 		helpString += "6 is the number of otus containing sequences from groupA, 1 is the number of otus containing sequences from groupB, and 2 is the number of otus containing sequences from groupC.\n";
 		helpString += "The label parameter allows you to select what distance levels you would like a output files created for, and is separated by dashes.\n";
         helpString += "The persample parameter allows you to find a consensus taxonomy for each group. Default=f\n";
+        helpString += "The relabund parameter allows you to indicate you want the summary file values to be relative abundances rather than raw abundances. Default=F. \n";
 		helpString += "The default value for label is all labels in your inputfile.\n";
+        helpString += "The output parameter allows you to specify format of your summary file. Options are simple and detail. The default is detail.\n";
+        helpString += "The printlevel parameter allows you to specify taxlevel of your summary file to print to. Options are 1 to the maz level in the file.  The default is -1, meaning max level.  If you select a level greater than the level your sequences classify to, mothur will print to the level your max level. \n";
 		helpString += "The cutoff parameter allows you to specify a consensus confidence threshold for your otu taxonomy output.  The default is 51, meaning 51%. Cutoff cannot be below 51.\n";
 		helpString += "The probs parameter shuts off the outputting of the consensus confidence results. The default is true, meaning you want the confidence to be shown.\n";
         helpString += "The threshold parameter allows you to specify a cutoff for the taxonomy file that is being inputted. Once the classification falls below the threshold the mothur will refer to it as unclassified when calculating the concensus.  This feature is similar to adjusting the cutoff in classify.seqs. Default=0.\n";
@@ -160,14 +164,6 @@ ClassifyOtuCommand::ClassifyOtuCommand(string option)  {
 					if (path == "") {	parameters["taxonomy"] = inputDir + it->second;		}
 				}
 				
-				it = parameters.find("reftaxonomy");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = m->hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["reftaxonomy"] = inputDir + it->second;		}
-				}
-				
 				it = parameters.find("group");
 				//user has given a template file
 				if(it != parameters.end()){ 
@@ -208,10 +204,6 @@ ClassifyOtuCommand::ClassifyOtuCommand(string option)  {
 			}
 			else if (taxfile == "not open") { abort = true; }
 			else { m->setTaxonomyFile(taxfile); }
-			
-			refTaxonomy = validParameter.validFile(parameters, "reftaxonomy", true);
-			if (refTaxonomy == "not found") { refTaxonomy = ""; m->mothurOut("reftaxonomy is not required, but if given will keep the rankIDs in the summary file static."); m->mothurOutEndLine(); }
-			else if (refTaxonomy == "not open") { abort = true; }
 	
 			namefile = validParameter.validFile(parameters, "name", true);
 			if (namefile == "not open") { namefile = ""; abort = true; }	
@@ -262,6 +254,15 @@ ClassifyOtuCommand::ClassifyOtuCommand(string option)  {
             
             temp = validParameter.validFile(parameters, "persample", false);		if (temp == "not found"){	temp = "f";		}
 			persample = m->isTrue(temp);
+            
+            temp = validParameter.validFile(parameters, "relabund", false);		if (temp == "not found"){	temp = "false";			}
+            relabund = m->isTrue(temp);
+            
+            temp = validParameter.validFile(parameters, "printlevel", false);		if (temp == "not found"){	temp = "-1";		}
+            m->mothurConvert(temp, printlevel);
+            
+            output = validParameter.validFile(parameters, "output", false);		if(output == "not found"){	output = "detail"; }
+            if ((output != "simple") && (output != "detail")) { m->mothurOut(output + " is not a valid output form. Options are simple and detail. I will use detail."); m->mothurOutEndLine(); output = "detail"; }
 			
             if ((groupfile == "") && (countfile == "")) { if (persample) { m->mothurOut("persample is only valid with a group file, or count file with group information. Setting persample=f.\n"); persample = false; } 
             }
@@ -400,7 +401,7 @@ int ClassifyOtuCommand::execute(){
 	}
 }
 //**********************************************************************************************************************
-vector<string> ClassifyOtuCommand::findConsensusTaxonomy(vector<string> names, int& size, string& conTax) {
+vector<string> ClassifyOtuCommand::findConsensusTaxonomy(vector<string> names, int& size, string& conTax, string group) {
 	try{
 		conTax = "";
 		vector<string> allNames;
@@ -412,53 +413,73 @@ vector<string> ClassifyOtuCommand::findConsensusTaxonomy(vector<string> names, i
 		
 		size = 0;
 		for (int i = 0; i < names.size(); i++) {
-	
-			//if namesfile include the names
-			if (namefile != "") {
-	
-				//is this sequence in the name file - namemap maps seqName -> repSeqName
-				it2 = nameMap.find(names[i]);
-				
-				if (it2 == nameMap.end()) { //this name is not in name file, skip it
-					m->mothurOut(names[i] + " is not in your name file.  I will not include it in the consensus."); m->mothurOutEndLine();
-				}else{
-					
-					//is this sequence in the taxonomy file - look for repSeqName since we are assuming the taxonomy file is unique
-					it = taxMap.find(it2->second);
-			
-					if (it == taxMap.end()) { //this name is not in taxonomy file, skip it
-					
-						if (names[i] != it2->second) { m->mothurOut(names[i] + " is represented by " +  it2->second + " and is not in your taxonomy file.  I will not include it in the consensus."); m->mothurOutEndLine(); }
-						else {  m->mothurOut(names[i] + " is not in your taxonomy file.  I will not include it in the consensus."); m->mothurOutEndLine(); }
-					}else{
-				
-						//add seq to tree
-						phylo->addSeqToTree(names[i], it->second);
-						size++;
-						allNames.push_back(names[i]);
-					}
-				}
-				
-			}else{
-				//is this sequence in the taxonomy file - look for repSeqName since we are assuming the taxonomy file is unique
-				it = taxMap.find(names[i]);
-		
-				if (it == taxMap.end()) { //this name is not in taxonomy file, skip it
-					m->mothurOut(names[i] + " is not in your taxonomy file.  I will not include it in the consensus."); m->mothurOutEndLine();
-				}else{
+            
+            if (group != "") { //no need to check for name file, names already added in previous step
+                //is this sequence in the taxonomy file - look for repSeqName since we are assuming the taxonomy file is unique
+                it = taxMap.find(names[i]);
+                
+                if (it == taxMap.end()) { //this name is not in taxonomy file, skip it
+                    m->mothurOut("[WARNING]: " + names[i] + " is not in your taxonomy file.  I will not include it in the consensus."); m->mothurOutEndLine();
+                }else{
                     if (countfile != "") {
-                        int numDups = ct->getNumSeqs(names[i]); 
+                        int numDups = ct->getGroupCount(names[i], group);
                         for (int j = 0; j < numDups; j++) {  phylo->addSeqToTree(names[i], it->second);  }
                         size += numDups;
                     }else{
-					//add seq to tree
+                        //add seq to tree
                         phylo->addSeqToTree(names[i], it->second);
-                        size++;  
+                        size++;
                     }
                     allNames.push_back(names[i]);
-				}
-			}
+                }
 
+            }else {
+                //if namesfile include the names
+                if (namefile != "") {
+                    
+                    //is this sequence in the name file - namemap maps seqName -> repSeqName
+                    it2 = nameMap.find(names[i]);
+                    
+                    if (it2 == nameMap.end()) { //this name is not in name file, skip it
+                        m->mothurOut(names[i] + " is not in your name file.  I will not include it in the consensus."); m->mothurOutEndLine();
+                    }else{
+                        
+                        //is this sequence in the taxonomy file - look for repSeqName since we are assuming the taxonomy file is unique
+                        it = taxMap.find(it2->second);
+                        
+                        if (it == taxMap.end()) { //this name is not in taxonomy file, skip it
+                            
+                            if (names[i] != it2->second) { m->mothurOut(names[i] + " is represented by " +  it2->second + " and is not in your taxonomy file.  I will not include it in the consensus."); m->mothurOutEndLine(); }
+                            else {  m->mothurOut(names[i] + " is not in your taxonomy file.  I will not include it in the consensus."); m->mothurOutEndLine(); }
+                        }else{
+                            
+                            //add seq to tree
+                            phylo->addSeqToTree(names[i], it->second);
+                            size++;
+                            allNames.push_back(names[i]);
+                        }
+                    }
+                    
+                }else{
+                    //is this sequence in the taxonomy file - look for repSeqName since we are assuming the taxonomy file is unique
+                    it = taxMap.find(names[i]);
+                    
+                    if (it == taxMap.end()) { //this name is not in taxonomy file, skip it
+                        m->mothurOut("[WARNING]: " + names[i] + " is not in your taxonomy file.  I will not include it in the consensus."); m->mothurOutEndLine();
+                    }else{
+                        if (countfile != "") {
+                            int numDups = ct->getNumSeqs(names[i]); 
+                            for (int j = 0; j < numDups; j++) {  phylo->addSeqToTree(names[i], it->second);  }
+                            size += numDups;
+                        }else{
+                            //add seq to tree
+                            phylo->addSeqToTree(names[i], it->second);
+                            size++;  
+                        }
+                        allNames.push_back(names[i]);
+                    }
+                }
+            }
 			
 			if (m->control_pressed) { delete phylo; return allNames; }
 			
@@ -493,7 +514,7 @@ vector<string> ClassifyOtuCommand::findConsensusTaxonomy(vector<string> names, i
 				
 			//is this taxonomy above cutoff
 			int consensusConfidence = ceil((bestChildSize / (float) size) * 100);
-			
+            
 			if (consensusConfidence >= cutoff) { //if yes, add it
 				if (probs) {
 					conTax += bestChild.name + "(" + toString(consensusConfidence) + ");";
@@ -508,30 +529,20 @@ vector<string> ClassifyOtuCommand::findConsensusTaxonomy(vector<string> names, i
 			//move down a level
 			currentNode = bestChild;
 		}
-		
-		if (myLevel != phylo->getMaxLevel()) {
-			while (myLevel != phylo->getMaxLevel()) {
-                if (probs) {
-                    conTax += "unclassified(100);";
-                }else{
-                    conTax += "unclassified;";
-                }
-				myLevel++;
-			}
-		}		
-		if (conTax == "") {  conTax = "no_consensus;";  }
+        
+        if (conTax == "") {  conTax = "unknown;";  }
+        
+		if (myLevel != phylo->getMaxLevel()) {  conTax = m->addUnclassifieds(conTax, phylo->getMaxLevel(), probs);  }
 		
 		delete phylo;	
 		
 		return allNames;
-			
 	}
 	catch(exception& e) {
 		m->errorOut(e, "ClassifyOtuCommand", "findConsensusTaxonomy");
 		exit(1);
 	}
 }
-
 //**********************************************************************************************************************
 int ClassifyOtuCommand::process(ListVector* processList) {
 	try{
@@ -557,43 +568,26 @@ int ClassifyOtuCommand::process(ListVector* processList) {
 		out << "OTU\tSize\tTaxonomy" << endl;
 		
 		PhyloSummary* taxaSum;
-        if (countfile != "") {
-            if (refTaxonomy != "") { taxaSum = new PhyloSummary(refTaxonomy, ct,false);  }
-            else {  taxaSum = new PhyloSummary(ct,false); }
-		}else {
-            if (refTaxonomy != "") { taxaSum = new PhyloSummary(refTaxonomy, groupMap,false);  }
-            else {  taxaSum = new PhyloSummary(groupMap,false); }
-        }
+        if (countfile != "") { taxaSum = new PhyloSummary(ct,relabund, printlevel); }
+        else { taxaSum = new PhyloSummary(groupMap,relabund, printlevel); }
         
-        vector<ofstream*> outSums;
-        vector<ofstream*> outs;
+        vector<string> outs;
         vector<PhyloSummary*> taxaSums;
         map<string, int> groupIndex;
         if (persample) {
             for (int i = 0; i < groups.size(); i++) {
                 groupIndex[groups[i]] = i;
-                ofstream* temp = new ofstream();
                 variables["[distance]"] = processList->getLabel() + "." + groups[i];
                 string outputFile = getOutputFileName("constaxonomy", variables);
-                m->openOutputFile(outputFile, *temp);
-                (*temp) << "OTU\tSize\tTaxonomy" << endl;
-                outs.push_back(temp);
+                ofstream temp;
+                m->openOutputFile(outputFile, temp);
+                outs.push_back(outputFile);
+                temp << "OTU\tSize\tTaxonomy" << endl;
                 outputNames.push_back(outputFile); outputTypes["constaxonomy"].push_back(outputFile);
                 
-                ofstream* tempSum = new ofstream();
-                string outputSumFile = getOutputFileName("taxsummary", variables);
-                m->openOutputFile(outputSumFile, *tempSum);
-                outSums.push_back(tempSum);
-                outputNames.push_back(outputSumFile); outputTypes["taxsummary"].push_back(outputSumFile);
-                
                 PhyloSummary* taxaSumt;
-                if (countfile != "") {
-                    if (refTaxonomy != "") { taxaSumt = new PhyloSummary(refTaxonomy, ct, false);  }
-                    else {  taxaSumt = new PhyloSummary(ct, false); }
-                }else {
-                    if (refTaxonomy != "") { taxaSumt = new PhyloSummary(refTaxonomy, groupMap,false);  }
-                    else {  taxaSumt = new PhyloSummary(groupMap,false); }
-                }
+                if (countfile != "") { taxaSumt = new PhyloSummary(ct, relabund, printlevel);
+                }else { taxaSumt = new PhyloSummary(groupMap,relabund, printlevel); }
                 taxaSums.push_back(taxaSumt);
             }
         }
@@ -610,7 +604,7 @@ int ClassifyOtuCommand::process(ListVector* processList) {
             vector<string> thisNames;
             m->splitAtComma(binnames, thisNames);
             
-			names = findConsensusTaxonomy(thisNames, size, conTax);
+			names = findConsensusTaxonomy(thisNames, size, conTax, "");
 		
 			if (m->control_pressed) { break; }
 
@@ -685,12 +679,13 @@ int ClassifyOtuCommand::process(ListVector* processList) {
                 }
                 
                 for (itParsed = parsedNames.begin(); itParsed != parsedNames.end(); itParsed++) {
-                    vector<string> theseNames = findConsensusTaxonomy(itParsed->second, size, conTax);
+                    vector<string> theseNames = findConsensusTaxonomy(itParsed->second, size, conTax, itParsed->first);
                     
                     if (m->control_pressed) { break; }
                     
-                    
-                    (*outs[groupIndex[itParsed->first]]) << binLabels[i] << '\t' << size << '\t' << conTax << endl;
+                    ofstream out; m->openOutputFileAppend(outs[groupIndex[itParsed->first]], out);
+                    out << binLabels[i] << '\t' << size << '\t' << conTax << endl;
+                    out.close();
                     
                     string noConfidenceConTax = conTax;
                     m->removeConfidences(noConfidenceConTax);
@@ -714,16 +709,18 @@ int ClassifyOtuCommand::process(ListVector* processList) {
 		out.close();
 		
 		//print summary file
-		taxaSum->print(outSum);
+		taxaSum->print(outSum, output);
 		outSum.close();
         
         if (persample) {
             for (int i = 0; i < groups.size(); i++) {
-                (*outs[i]).close();
-                taxaSums[i]->print(*outSums[i]);
-                (*outSums[i]).close();
-                delete outs[i];
-                delete outSums[i];
+                ofstream outSums;
+                variables["[distance]"] = processList->getLabel() + "." + groups[i];
+                string outputSumFile = getOutputFileName("taxsummary", variables);
+                m->openOutputFile(outputSumFile, outSums);
+                outputNames.push_back(outputSumFile); outputTypes["taxsummary"].push_back(outputSumFile);
+                taxaSums[i]->print(outSums, output);
+                outSums.close();
                 delete taxaSums[i];
             }
         }
@@ -739,34 +736,6 @@ int ClassifyOtuCommand::process(ListVector* processList) {
 	}
 }
 /**************************************************************************************************/
-string ClassifyOtuCommand::addUnclassifieds(string tax, int maxlevel) {
-	try{
-		string newTax, taxon;
-		int level = 0;
-		
-		//keep what you have counting the levels
-		while (tax.find_first_of(';') != -1) {
-			//get taxon
-			taxon = tax.substr(0,tax.find_first_of(';'))+';';
-			tax = tax.substr(tax.find_first_of(';')+1, tax.length());
-			newTax += taxon;
-			level++;
-		}
-		
-		//add "unclassified" until you reach maxLevel
-		while (level < maxlevel) {
-			newTax += "unclassified;";
-			level++;
-		}
-		
-		return newTax;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "ClassifyOtuCommand", "addUnclassifieds");
-		exit(1);
-	}
-}
-/**************************************************************************************************/
 int ClassifyOtuCommand::processTaxMap() {
     try{
         
