@@ -8,6 +8,7 @@
 
 #include "lefsecommand.h"
 #include "linearalgebra.h"
+#include "sharedutilities.h"
 
 //**********************************************************************************************************************
 vector<string> LefseCommand::setParameters(){
@@ -20,7 +21,7 @@ vector<string> LefseCommand::setParameters(){
 		//CommandParameter pclasses("classes", "String", "", "", "", "", "","",false,false); parameters.push_back(pclasses);
         CommandParameter palpha("aalpha", "Number", "", "0.05", "", "", "","",false,false); parameters.push_back(palpha);
         CommandParameter pwalpha("walpha", "Number", "", "0.05", "", "", "","",false,false); parameters.push_back(pwalpha);
-        
+        CommandParameter psets("sets", "String", "", "", "", "", "","",false,false); parameters.push_back(psets);
         CommandParameter plda("lda", "Number", "", "2.0", "", "", "","",false,false); parameters.push_back(plda);
         CommandParameter pwilc("wilc", "Boolean", "", "T", "", "", "","",false,false); parameters.push_back(pwilc);
         CommandParameter pnormmillion("norm", "Boolean", "", "T", "", "", "","",false,false); parameters.push_back(pnormmillion);
@@ -68,6 +69,7 @@ string LefseCommand::getHelpString(){
         helpString += "The wilc parameter is used to indicate whether to perform the Wilcoxon test. Default=T. \n";
         helpString += "The iters parameter is used to set the number of bootstrap iteration for LDA. Default=30. \n";
         //helpString += "The wilcsamename parameter is used to indicate whether perform the wilcoxon test only among the subclasses with the same name. Default=F. \n";
+        helpString += "The sets parameter allows you to specify which of the sets in your designfile you would like to analyze. The set names are separated by dashes. THe default is all sets in the designfile.\n";
         helpString += "The curv parameter is used to set whether perform the wilcoxon testing the Curtis's approach [BETA VERSION] Default=F. \n";
         helpString += "The norm parameter is used to multiply relative abundances by 1000000. Recommended when very low values are present. Default=T. \n";
         helpString += "The fboots parameter is used to set the subsampling fraction value for each bootstrap iteration. Default=0.67. \n";
@@ -249,6 +251,12 @@ LefseCommand::LefseCommand(string option)  {
 			if (temp == "not found") { temp = "10"; }
 			m->mothurConvert(temp, minC);
             
+            sets = validParameter.validFile(parameters, "sets", false);
+            if (sets == "not found") { sets = ""; }
+            else {
+                m->splitAtDash(sets, Sets);
+            }
+            
             multiClassStrat = validParameter.validFile(parameters, "multiclass", false);
             if (multiClassStrat == "not found"){	multiClassStrat = "onevall";		}
 			if ((multiClassStrat != "onevall") && (multiClassStrat != "onevone")) { m->mothurOut("Invalid multiclass option: choices are onevone or onevall."); m->mothurOutEndLine(); abort=true; }
@@ -275,6 +283,18 @@ int LefseCommand::execute(){
         //if user did not select class use first column
         if (mclass == "") {  mclass = designMap.getDefaultClass(); m->mothurOut("\nYou did not provide a class, using " + mclass +".\n\n"); if (subclass == "") { subclass = mclass; } }
         
+        if (Sets.size() != 0) { //user has picked sets find groups to include from lookup
+            //make sure sets are all in designMap
+            SharedUtil* util = new SharedUtil();
+            vector<string> dGroups = designMap.getCategory(mclass);
+            util->setGroups(Sets, dGroups);
+            delete util;
+            
+            designMap.setDefaultClass(mclass);
+            vector<string> groupsToSelect = designMap.getNamesGroups(Sets);
+            m->setGroups(groupsToSelect);
+        }
+        
         InputData input(sharedfile, "sharedfile");
         vector<SharedRAbundFloatVector*> lookup = input.getSharedRAbundFloatVectors();
         string lastLabel = lookup[0]->getLabel();
@@ -283,7 +303,6 @@ int LefseCommand::execute(){
         set<string> processedLabels;
         set<string> userLabels = labels;
         
-        
         //as long as you are not at the end of the file or done wih the lines you want
         while((lookup[0] != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
             
@@ -357,7 +376,7 @@ int LefseCommand::execute(){
 		m->mothurOut("Output File Names: "); m->mothurOutEndLine();
 		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]); m->mothurOutEndLine();	}
 		m->mothurOutEndLine();
-        srand(time(NULL));
+        srand((unsigned)time(NULL));
         return 0;
 		
     }
@@ -767,8 +786,8 @@ map<int, double> LefseCommand::testLDA(vector<SharedRAbundFloatVector*>& lookup,
         int fractionNumGroups = numGroups * fBoots; //rfk
         minCl = (int)((float)(minCl*fBoots*fBoots*0.05));
         minCl = max(minCl, 1);
-        
-        if (m->debug) { m->mothurOut("[DEBUG]: about to start iters. \n."); }
+ 
+        if (m->debug) { m->mothurOut("[DEBUG]: about to start iters. FractionGroups = " + toString(fractionNumGroups) + "\n."); }
         
         vector< vector< vector<double> > > results;//[iters][numComparison][numOTUs]
         for (int j = 0; j < iters; j++) {
@@ -782,7 +801,9 @@ map<int, double> LefseCommand::testLDA(vector<SharedRAbundFloatVector*>& lookup,
             for (int h = 0; h < 1000; h++) { //generate a vector of length fractionNumGroups with range 0 to numGroups-1
                 save = h;
                 rand_s.clear();
-                for (int k = 0; k < fractionNumGroups; k++) {  rand_s.push_back(m->getRandomIndex(numGroups-1)); }
+                for (int k = 0; k < fractionNumGroups; k++) {  int index = m->getRandomIndex(numGroups-1); rand_s.push_back(index);
+                    //if (m->debug) { m->mothurOut("[DEBUG]: index = " + toString(index) + "\n."); }
+                }
                 if (!contastWithinClassesOrFewPerClass(adjustedLookup, rand_s, minCl, class2GroupIndex, indexToClass)) { h+=1000; save += 1000; } //break out of loop
             }
             if (m->control_pressed) { return sigOTUS; }
@@ -950,13 +971,15 @@ vector< vector<double> > LefseCommand::lda(vector< vector<double> >& adjustedLoo
 //modelled after lefse.py contast_within_classes_or_few_per_class function
 bool LefseCommand::contastWithinClassesOrFewPerClass(vector< vector<double> >& lookup, vector<int> rands, int minCl, map<string, vector<int> > class2GroupIndex, map<int, string> indexToClass) {
     try {
-        set<string> cls;
+        map<string, int> cls;
         int countFound = 0;
         
         for (int i = 0; i < rands.size(); i++) { //fill cls with the classes represented in the random selection
             for (map<string, vector<int> >::iterator it = class2GroupIndex.begin(); it != class2GroupIndex.end(); it++) {
                 if (m->inUsersGroups(rands[i], (it->second))) {
-                    cls.insert(it->first);
+                    map<string, int>::iterator itClass = cls.find(it->first);
+                    if (itClass != cls.end()) { itClass->second++; }
+                    else { cls[it->first] = 1;  }
                     countFound++;
                 }
             }
@@ -967,8 +990,8 @@ bool LefseCommand::contastWithinClassesOrFewPerClass(vector< vector<double> >& l
         
         if (cls.size() < class2GroupIndex.size()) { return true; } //some classes are not present in sampling
         
-        for (set<string>::iterator it = cls.begin(); it != cls.end(); it++) {
-            if (cls.count(*it) < minCl) { return true; } //this sampling has class count below minimum
+        for (map<string, int>::iterator itClass = cls.begin(); itClass != cls.end(); itClass++) {
+            if (itClass->second < minCl) { return true; } //this sampling has class count below minimum
         }
         
         //for this otu
