@@ -11,6 +11,7 @@
 #include "sequence.hpp"
 #include "listvector.hpp"
 #include "counttable.h"
+#include "fastqread.h"
 
 //**********************************************************************************************************************
 vector<string> RemoveSeqsCommand::setParameters(){	
@@ -27,6 +28,7 @@ vector<string> RemoveSeqsCommand::setParameters(){
 		CommandParameter paccnos("accnos", "InputTypes", "", "", "none", "none", "none","",false,true,true); parameters.push_back(paccnos);
 		CommandParameter pdups("dups", "Boolean", "", "T", "", "", "","",false,false); parameters.push_back(pdups);
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
+        CommandParameter pformat("format", "Multiple", "sanger-illumina-solexa-illumina1.8+", "illumina1.8+", "", "", "","",false,false,true); parameters.push_back(pformat);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
 		
@@ -46,6 +48,7 @@ string RemoveSeqsCommand::getHelpString(){
 		helpString += "The remove.seqs command reads an .accnos file and at least one of the following file types: fasta, name, group, count, list, taxonomy, quality, fastq or alignreport file.\n";
 		helpString += "It outputs a file containing the sequences NOT in the .accnos file.\n";
 		helpString += "The remove.seqs command parameters are accnos, fasta, name, group, count, list, taxonomy, qfile, alignreport, fastq and dups.  You must provide accnos and at least one of the file parameters.\n";
+        helpString += "The format parameter is used to indicate whether your sequences are sanger, solexa, illumina1.8+ or illumina, default=illumina1.8+.\n";
 		helpString += "The dups parameter allows you to remove the entire line from a name file if you remove any name from the line. default=true. \n";
 		helpString += "The remove.seqs command should be in the following format: remove.seqs(accnos=yourAccnos, fasta=yourFasta).\n";
 		helpString += "Example remove.seqs(accnos=amazon.accnos, fasta=amazon.fasta).\n";
@@ -305,6 +308,13 @@ RemoveSeqsCommand::RemoveSeqsCommand(string option)  {
                     parser.getNameFile(files);
                 }
             }
+            
+            format = validParameter.validFile(parameters, "format", false);		if (format == "not found"){	format = "illumina1.8+";	}
+            
+            if ((format != "sanger") && (format != "illumina") && (format != "illumina1.8+") && (format != "solexa"))  {
+                m->mothurOut(format + " is not a valid format. Your format choices are sanger, solexa, illumina1.8+ and illumina, aborting." ); m->mothurOutEndLine();
+                abort=true;
+            }
 		}
 
 	}
@@ -417,6 +427,7 @@ int RemoveSeqsCommand::readFasta(){
 		bool wroteSomething = false;
 		int removedCount = 0;
 		
+        set<string> uniqueNames;
 		while(!in.eof()){
 			if (m->control_pressed) { in.close();  out.close();  m->mothurRemove(outputFileName);  return 0; }
 			
@@ -432,9 +443,14 @@ int RemoveSeqsCommand::readFasta(){
 			if (name != "") {
 				//if this name is in the accnos file
 				if (names.count(name) == 0) {
-					wroteSomething = true;
+                    if (uniqueNames.count(name) == 0) { //this name hasn't been seen yet
+                        uniqueNames.insert(name);
+                        wroteSomething = true;
 					
-                    currSeq.printSequence(out);
+                        currSeq.printSequence(out);
+                    }else {
+                        m->mothurOut("[WARNING]: " + name + " is in your fasta file more than once.  Mothur requires sequence names to be unique. I will only add it once.\n");
+                    }
 				}else {  removedCount++;  }
 			}
 			m->gobble(in);
@@ -473,30 +489,27 @@ int RemoveSeqsCommand::readFastq(){
 		ofstream out;
 		m->openOutputFile(outputFileName, out);
         
-		
+		set<string> uniqueNames;
 		while(!in.eof()){
 			
 			if (m->control_pressed) { in.close(); out.close(); m->mothurRemove(outputFileName); return 0; }
 			
-			//read sequence name
-			string input = m->getline(in); m->gobble(in);
-			
-            string outputString = input + "\n";
+            //read sequence name
+            bool ignore;
+            FastqRead fread(in, ignore, format); m->gobble(in);
             
-			if (input[0] == '@') {
-                //get rest of lines
-                outputString += m->getline(in) + "\n"; m->gobble(in);
-                outputString += m->getline(in) + "\n"; m->gobble(in);
-                outputString += m->getline(in) + "\n"; m->gobble(in);
-                
-                vector<string> splits = m->splitWhiteSpace(input);
-                string name = splits[0];
-                name = name.substr(1);
-                m->checkName(name);
+            if (!ignore) {
+                string name = fread.getName();
                 
                 if (names.count(name) == 0) {
-					wroteSomething = true;
-                    out << outputString;
+                    if (uniqueNames.count(name) == 0) { //this name hasn't been seen yet
+                        wroteSomething = true;
+                        fread.printFastq(out);
+                        uniqueNames.insert(name);
+                    }else {
+                        m->mothurOut("[WARNING]: " + name + " is in your fastq file more than once.  Mothur requires sequence names to be unique. I will only add it once.\n");
+                    }
+
                 }else { removedCount++; }
             }
             
@@ -540,7 +553,7 @@ int RemoveSeqsCommand::readQual(){
 		bool wroteSomething = false;
 		int removedCount = 0;
 		
-		
+		set<string> uniqueNames;
 		while(!in.eof()){	
 			string saveName = "";
 			string name = "";
@@ -572,9 +585,14 @@ int RemoveSeqsCommand::readQual(){
             }
             
 			if (names.count(saveName) == 0) {
-				wroteSomething = true;
+                if (uniqueNames.count(saveName) == 0) { //this name hasn't been seen yet
+                    uniqueNames.insert(saveName);
+                    wroteSomething = true;
 				
-				out << name << endl << scores;
+                    out << name << endl << scores;
+                }else {
+                    m->mothurOut("[WARNING]: " + saveName + " is in your qfile more than once.  Mothur requires sequence names to be unique. I will only add it once.\n");
+                }
 			}else {  removedCount++;  }
 			
 			m->gobble(in);
@@ -621,6 +639,7 @@ int RemoveSeqsCommand::readCount(){
         string test = headers; vector<string> pieces = m->splitWhiteSpace(test);
         
         string name, rest; int thisTotal; rest = "";
+        set<string> uniqueNames;
         while (!in.eof()) {
             
             if (m->control_pressed) { in.close();  out.close();  m->mothurRemove(outputFileName);  return 0; }
@@ -631,8 +650,13 @@ int RemoveSeqsCommand::readCount(){
             if (m->debug) { m->mothurOut("[DEBUG]: " + name + '\t' + rest + "\n"); }
             
             if (names.count(name) == 0) {
-                out << name << '\t' << thisTotal << '\t' << rest << endl;
-                wroteSomething = true;
+                if (uniqueNames.count(name) == 0) { //this name hasn't been seen yet
+                    uniqueNames.insert(name);
+                    out << name << '\t' << thisTotal << '\t' << rest << endl;
+                    wroteSomething = true;
+                }else {
+                    m->mothurOut("[WARNING]: " + name + " is in your count file more than once.  Mothur requires sequence names to be unique. I will only add it once.\n");
+                }
             }else { removedCount += thisTotal; }
         }
         in.close();
@@ -673,9 +697,11 @@ int RemoveSeqsCommand::readList(){
 		bool wroteSomething = false;
 		int removedCount = 0;
 		
+        
 		while(!in.eof()){
 			
 			removedCount = 0;
+            set<string> uniqueNames;
 			
 			//read in list vector
 			ListVector list(in);
@@ -709,7 +735,14 @@ int RemoveSeqsCommand::readList(){
                 for (int j = 0; j < bnames.size(); j++) {
 					string name = bnames[j];
                     //if that name is in the .accnos file, add it
-					if (names.count(name) == 0) {  newNames += name + ",";  }
+					if (names.count(name) == 0) {
+                        if (uniqueNames.count(name) == 0) { //this name hasn't been seen yet
+                            uniqueNames.insert(name);
+                            newNames += name + ",";
+                        }else {
+                            m->mothurOut("[WARNING]: " + name + " is in your list file more than once.  Mothur requires sequence names to be unique. I will only add it once.\n");
+                        }
+                    }
 					else {  removedCount++;  }
                 }
 
@@ -726,7 +759,7 @@ int RemoveSeqsCommand::readList(){
 				wroteSomething = true;
 				newList.setLabels(newBinLabels);
                 newList.printHeaders(out);
-				newList.print(out);
+				newList.print(out, false);
 
 			}
 			
@@ -767,6 +800,7 @@ int RemoveSeqsCommand::readName(){
 		bool wroteSomething = false;
 		int removedCount = 0;
 		
+        set<string> uniqueNames;
 		while(!in.eof()){
 			if (m->control_pressed) { in.close();  out.close();  m->mothurRemove(outputFileName);  return 0; }
 			
@@ -776,46 +810,58 @@ int RemoveSeqsCommand::readName(){
 			vector<string> parsedNames;
 			m->splitAtComma(secondCol, parsedNames);
 			
-			vector<string> validSecond;  validSecond.clear();
+            vector<string> validSecond;  validSecond.clear(); vector<string> parsedNames2;
+            bool parsedError = false;
 			for (int i = 0; i < parsedNames.size(); i++) {
 				if (names.count(parsedNames[i]) == 0) {
-					validSecond.push_back(parsedNames[i]);
+                    if (uniqueNames.count(parsedNames[i]) == 0) { //this name hasn't been seen yet
+                        uniqueNames.insert(parsedNames[i]);
+                        validSecond.push_back(parsedNames[i]);
+                        parsedNames2.push_back(parsedNames[i]);
+                    }else {
+                        m->mothurOut("[WARNING]: " + parsedNames[i] + " is in your name file more than once.  Mothur requires sequence names to be unique. I will only add it once.\n");
+                        parsedError = true;
+                    }
 				}
 			}
+            
+            if (parsedError) {  parsedNames = parsedNames2; }
 			
 			if ((dups) && (validSecond.size() != parsedNames.size())) {  //if dups is true and we want to get rid of anyone, get rid of everyone
 				for (int i = 0; i < parsedNames.size(); i++) {  names.insert(parsedNames[i]);  }
 				removedCount += parsedNames.size();
 			}else {
-				removedCount += parsedNames.size()-validSecond.size();
-				//if the name in the first column is in the set then print it and any other names in second column also in set
-				if (names.count(firstCol) == 0) {
-					
-					wroteSomething = true;
-					
-					out << firstCol << '\t';
-					
-					//you know you have at least one valid second since first column is valid
-					for (int i = 0; i < validSecond.size()-1; i++) {  out << validSecond[i] << ',';  }
-					out << validSecond[validSecond.size()-1] << endl;
-					
-					//make first name in set you come to first column and then add the remaining names to second column
-				}else {
-					
-					//you want part of this row
-					if (validSecond.size() != 0) {
-						
-						wroteSomething = true;
-						
-						out << validSecond[0] << '\t';
-                        //we are changing the unique name in the fasta file
-                        uniqueMap[firstCol] = validSecond[0];
-						
-						//you know you have at least one valid second since first column is valid
-						for (int i = 0; i < validSecond.size()-1; i++) {  out << validSecond[i] << ',';  }
-						out << validSecond[validSecond.size()-1] << endl;
-					}
-				}
+                if (validSecond.size() != 0) {
+                    removedCount += parsedNames.size()-validSecond.size();
+                    //if the name in the first column is in the set then print it and any other names in second column also in set
+                    if (names.count(firstCol) == 0) {
+                        
+                        wroteSomething = true;
+                        
+                        out << firstCol << '\t';
+                        
+                        //you know you have at least one valid second since first column is valid
+                        for (int i = 0; i < validSecond.size()-1; i++) {  out << validSecond[i] << ',';  }
+                        out << validSecond[validSecond.size()-1] << endl;
+                        
+                        //make first name in set you come to first column and then add the remaining names to second column
+                    }else {
+                        
+                        //you want part of this row
+                        if (validSecond.size() != 0) {
+                            
+                            wroteSomething = true;
+                            
+                            out << validSecond[0] << '\t';
+                            //we are changing the unique name in the fasta file
+                            uniqueMap[firstCol] = validSecond[0];
+                            
+                            //you know you have at least one valid second since first column is valid
+                            for (int i = 0; i < validSecond.size()-1; i++) {  out << validSecond[i] << ',';  }
+                            out << validSecond[validSecond.size()-1] << endl;
+                        }
+                    }
+                }
 			}
 			m->gobble(in);
 		}
@@ -854,6 +900,7 @@ int RemoveSeqsCommand::readGroup(){
 		bool wroteSomething = false;
 		int removedCount = 0;
 		
+        set<string> uniqueNames;
 		while(!in.eof()){
 			if (m->control_pressed) { in.close();  out.close();  m->mothurRemove(outputFileName);  return 0; }
 			
@@ -862,8 +909,13 @@ int RemoveSeqsCommand::readGroup(){
 			
 			//if this name is in the accnos file
 			if (names.count(name) == 0) {
-				wroteSomething = true;
-				out << name << '\t' << group << endl;
+                if (uniqueNames.count(name) == 0) { //this name hasn't been seen yet
+                    uniqueNames.insert(name);
+                    wroteSomething = true;
+                    out << name << '\t' << group << endl;
+                }else {
+                    m->mothurOut("[WARNING]: " + name + " is in your group file more than once.  Mothur requires sequence names to be unique. I will only add it once.\n");
+                }
 			}else {  removedCount++;  }
 					
 			m->gobble(in);
@@ -903,6 +955,7 @@ int RemoveSeqsCommand::readTax(){
 		bool wroteSomething = false;
 		int removedCount = 0;
 		
+        set<string> uniqueNames;
 		while(!in.eof()){
 			if (m->control_pressed) { in.close();  out.close();  m->mothurRemove(outputFileName);  return 0; }
 			
@@ -916,9 +969,14 @@ int RemoveSeqsCommand::readTax(){
             
 			//if this name is in the accnos file
 			if (names.count(name) == 0) {
-				wroteSomething = true;
+                if (uniqueNames.count(name) == 0) { //this name hasn't been seen yet
+                    uniqueNames.insert(name);
+                    wroteSomething = true;
             
-				out << name << '\t' << tax << endl;
+                    out << name << '\t' << tax << endl;
+                }else {
+                    m->mothurOut("[WARNING]: " + name + " is in your taxonomy file more than once.  Mothur requires sequence names to be unique. I will only add it once.\n");
+                }
 			}else {  removedCount++;  }
 					
 			m->gobble(in);
@@ -965,6 +1023,7 @@ int RemoveSeqsCommand::readAlign(){
 		}
 		out << endl;
 		
+        set<string> uniqueNames;
 		while(!in.eof()){
 			if (m->control_pressed) { in.close();  out.close();  m->mothurRemove(outputFileName);  return 0; }
 			
@@ -977,17 +1036,21 @@ int RemoveSeqsCommand::readAlign(){
 			
 			//if this name is in the accnos file
 			if (names.count(name) == 0) {
-				wroteSomething = true;
-				
-				out << name << '\t';
-				
-				//read rest
-				for (int i = 0; i < 15; i++) {  
-					if (!in.eof())	{	in >> junk;	 out << junk << '\t';	}
-					else			{	break;			}
-				}
-				out << endl;
-				
+                if (uniqueNames.count(name) == 0) { //this name hasn't been seen yet
+                    uniqueNames.insert(name);
+                    wroteSomething = true;
+                    
+                    out << name << '\t';
+                    
+                    //read rest
+                    for (int i = 0; i < 15; i++) {
+                        if (!in.eof())	{	in >> junk;	 out << junk << '\t';	}
+                        else			{	break;			}
+                    }
+                    out << endl;
+                }else {
+                    m->mothurOut("[WARNING]: " + name + " is in your alignreport file more than once.  Mothur requires sequence names to be unique. I will only add it once.\n");
+                }
 			}else {//still read just don't do anything with it
 				removedCount++;  
 				
