@@ -61,6 +61,7 @@ class CountTable {
         bool hasGroupInfo() { return hasGroups; }
         int getNumGroups() { return groups.size(); }
         vector<string> getNamesOfGroups() {  return groups;   }  //returns group names, if no group info vector is blank.
+        bool setNamesOfGroups(vector<string>);
         int addGroup(string);
         int removeGroup(string);
         
@@ -77,7 +78,8 @@ class CountTable {
         vector<int> getGroupCounts(string);  //returns group counts for a seq passed in, if no group info is in file vector is blank. Order is the same as the groups returned by getGroups function.
         int getGroupCount(string, string); //returns number of seqs for that group for that seq
         int getGroupCount(string); // returns total seqs for that group
-        int getNumSeqs(string); //returns total seqs for that seq, 0 if not found 
+        int getNumSeqs(string); //returns total seqs for that seq, 0 if not found
+        int setNumSeqs(string, int); //set total seqs for that seq, return -1 if not found
         int getNumSeqs() { return total; } //return total number of seqs
         int getNumUniqueSeqs() { return uniques; } //return number of unique/representative seqs
         int getGroupIndex(string); //returns index in getGroupCounts vector of specific group
@@ -86,7 +88,7 @@ class CountTable {
         vector<string> getNamesOfSeqs(string);
         int mergeCounts(string, string); //combines counts for 2 seqs, saving under the first name passed in.
         ListVector getListVector();
-        map<string, int> getNameMap();
+        map<string, int> getNameMap();  //sequenceName -> total number of sequences it represents
     
     private:
         string filename;
